#[non_exhaustive]#[repr(i32)]pub enum PenLineCap {
Flat = 0,
Square = 1,
Round = 2,
Triangle = 3,
}Expand description
How the ends of a dash (or a line) are drawn. Ordinals mirror
Noesis::PenLineCap.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Flat = 0
A cap that does not extend past the last point of the line.
Square = 1
A rectangle half the line thickness long.
Round = 2
A semicircle with diameter equal to the line thickness.
Triangle = 3
An isosceles right triangle.